==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/ScrubbingRuleEntryMatchVariable.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The variable to be scrubbed from the logs.
 */
public enum class ScrubbingRuleEntryMatchVariable(
    public val javaValue: com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable> {
    RequestHeaderNames(com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable.RequestHeaderNames),
    RequestCookieNames(com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable.RequestCookieNames),
    RequestArgNames(com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable.RequestArgNames),
    RequestPostArgNames(com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable.RequestPostArgNames),
    RequestJSONArgNames(com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable.RequestJSONArgNames),
    RequestIPAddress(com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable.RequestIPAddress),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable):
            ScrubbingRuleEntryMatchVariable =
            ScrubbingRuleEntryMatchVariable.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/ScrubbingRuleEntryMatchVariable.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The variable to be scrubbed from the logs.
 */
public enum class ScrubbingRuleEntryMatchVariable(
    public val javaValue: com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable> {
    RequestHeaderNames(com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable.RequestHeaderNames),
    RequestCookieNames(com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable.RequestCookieNames),
    RequestArgNames(com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable.RequestArgNames),
    RequestPostArgNames(com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable.RequestPostArgNames),
    RequestJSONArgNames(com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable.RequestJSONArgNames),
    RequestIPAddress(com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable.RequestIPAddress),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.enums.ScrubbingRuleEntryMatchVariable): ScrubbingRuleEntryMatchVariable =
            ScrubbingRuleEntryMatchVariable.values().first { it.javaValue == javaType }
    }
}
